==> hinemos_src-3.2.1.tar.gz: HinemosManager/src_notify/com/clustercontrol/notify/util/RunJob.java <==
/*

Copyright (C) 2006 NTT DATA Corporation

This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.

This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.

 */

package com.clustercontrol.notify.util;

import java.rmi.RemoteException;

import javax.ejb.CreateException;
import javax.ejb.FinderException;
import javax.naming.NamingException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.clustercontrol.bean.ConfirmConstant;
import com.clustercontrol.bean.ExecFacilityConstant;
import com.clustercontrol.bean.OutputBasicInfo;
import com.clustercontrol.bean.PriorityConstant;
import com.clustercontrol.jobmanagement.bean.JobTriggerInfo;
import com.clustercontrol.jobmanagement.bean.JobTriggerTypeConstant;
import com.clustercontrol.jobmanagement.ejb.session.JobControllerLocal;
import com.clustercontrol.jobmanagement.ejb.session.JobControllerUtil;
import com.clustercontrol.notify.bean.NotifyRequestMessage;
import com.clustercontrol.notify.ejb.entity.NotifyJobInfoData;
import com.clustercontrol.notify.ejb.entity.NotifyJobInfoLocal;
import com.clustercontrol.notify.ejb.entity.NotifyJobInfoPK;
import com.clustercontrol.notify.ejb.entity.NotifyJobInfoUtil;
import com.clustercontrol.util.Messages;

/**
 * ジョブを呼出すクラス<BR>
 *
 * @version 3.0.0
 * @since 3.0.0
 */
public class RunJob implements DependDbNotifier {
	/** ログ出力のインスタンス。 */
	protected static Log m_log = LogFactory.getLog( RunJob.class );

	/** 実行失敗通知用 */
	private NotifyJobInfoData m_jobInfo;

	/**
	 * ジョブ管理機能の指定されたジョブを呼出します。
	 * <p>含まれているログ出力情報を基にジョブを呼出します。<BR>
	 * ジョブの呼出に失敗した場合は、ログ出力情報の呼出失敗時の重要度で、監視管理機能のイベントへ通知します。
	 * 
	 * @param outputInfo　通知・抑制情報
	 * @throws RemoteException 
	 * @throws CreateException 
	 * @throws NamingException 
	 * @throws FinderException 
	 * 
	 * @see com.clustercontrol.jobmanagement.bean.JobTriggerInfo
	 * @see com.clustercontrol.monitor.factory.OutputEventLog#insertEventLog(LogOutputInfo, int)
	 */
	public synchronized void notify(NotifyRequestMessage message) throws RemoteException, NamingException, CreateException, FinderException {    	
		if(m_log.isDebugEnabled()){
			m_log.debug("notify() " + message); 
		}
		
		exectuteJob(message.getOutputInfo(), message.getNotifyId());
	}
	
	/**
	 * ジョブ管理機能の指定されたジョブを呼出します。
	 * <p>含まれているログ出力情報を基にジョブを呼出します。<BR>
	 * ジョブの呼出に失敗した場合は、ログ出力情報の呼出失敗時の重要度で、監視管理機能のイベントへ通知します。
	 * 
	 * @param outputInfo　通知・抑制情報
	 * @throws RemoteException 
	 * @throws CreateException 
	 * @throws NamingException 
	 * @throws FinderException 
	 * 
	 * @see com.clustercontrol.jobmanagement.bean.JobTriggerInfo
	 * @see com.clustercontrol.monitor.factory.OutputEventLog#insertEventLog(LogOutputInfo, int)
	 */
	public void exectuteJob(
			OutputBasicInfo outputInfo,
			String notifyId) {	
		if(m_log.isDebugEnabled()){
			m_log.debug("notify() " + outputInfo); 
		}
		
		/*
		 * 実行
		 */
		NotifyJobInfoLocal jobInfo = null;
		try {
			jobInfo = NotifyJobInfoUtil.getLocalHome().findByPrimaryKey(
					new NotifyJobInfoPK(notifyId, outputInfo.getPriority()));
			
			// 通知設定が「固定スコープ」となっていた場合は、ジョブに渡すファシリティIDを変更する
			if(jobInfo.getJobExecFacilityFlg() == ExecFacilityConstant.TYPE_FIX) {
				outputInfo.setFacilityId(jobInfo.getJobExecFacility());
			}

			// ジョブの実行契機を作成
			JobTriggerInfo triggerInfo = new JobTriggerInfo();
			triggerInfo.setTrigger_type(JobTriggerTypeConstant.TYPE_MONITOR);
			triggerInfo.setTrigger_info(outputInfo.getMonitorId()+"("+outputInfo.getPluginId()+")"); // 「監視項目ID(プラグインID)」形式で格納

			// ジョブ実行
			JobControllerLocal job = JobControllerUtil.getLocalHome().create();
			job.runJob(jobInfo.getJobunitId(), jobInfo.getJobId(), outputInfo, triggerInfo);

		}
		catch (Exception e) {
			if(jobInfo != null){
				m_jobInfo = new NotifyJobInfoData(
						jobInfo.getNotifyId(),
						jobInfo.getPriority(),
						jobInfo.getJobFailurePriority(),
						jobInfo.getJobunitId(),
						jobInfo.getJobId(),
						jobInfo.getValidFlg(),
						jobInfo.getJobExecFacilityFlg(),
						jobInfo.getJobExecFacility());
			}
			internalErrorNotify(notifyId, null, e.getMessage() + " : " + m_jobInfo);	
		}
	}

	/**
	 * 通知失敗時の内部エラー通知を定義します
	 */
	public void internalErrorNotify(String notifyId, String msgID, String detailMsg) {
		// FIXME
		//ジョブ失敗時の重要度を設定
		OutputBasicInfo outputInfo = new OutputBasicInfo();
		if(m_jobInfo != null){
			outputInfo.setPriority(m_jobInfo.getJobFailurePriority());
			String[] args1 = { m_jobInfo.getJobId() };
			outputInfo.setMessage(Messages.getString("message.monitor.41", args1));
		} else {
			outputInfo.setPriority(PriorityConstant.TYPE_CRITICAL);
			String[] args1 = { "unknown job id." };
			outputInfo.setMessage(Messages.getString("message.monitor.41", args1));
		}
		outputInfo.setMessageId("200");	// FIXME メッセージIDを精査する
		outputInfo.setMessageOrg(detailMsg);

		new OutputEvent().insertEventLog(outputInfo, ConfirmConstant.TYPE_UNCONFIRMED);
		
		m_jobInfo = null;
	}
}

==> hinemos_src-4.0.0.tar.gz: HinemosManager/src_notify/com/clustercontrol/notify/util/RunJob.java <==
/*

Copyright (C) 2006 NTT DATA Corporation

This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License
as published by the Free Software Foundation, version 2.

This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the GNU General Public License for more details.

 */

package com.clustercontrol.notify.util;

import java.rmi.RemoteException;

import javax.ejb.CreateException;
import javax.ejb.FinderException;
import javax.naming.NamingException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.clustercontrol.bean.PriorityConstant;
import com.clustercontrol.fault.InvalidSetting;
import com.clustercontrol.jobmanagement.bean.JobTriggerInfo;
import com.clustercontrol.jobmanagement.bean.JobTriggerTypeConstant;
import com.clustercontrol.jobmanagement.ejb.session.JobControllerLocal;
import com.clustercontrol.jobmanagement.ejb.session.JobControllerUtil;
import com.clustercontrol.jobmanagement.util.JobValidator;
import com.clustercontrol.monitor.bean.ConfirmConstant;
import com.clustercontrol.notify.bean.ExecFacilityConstant;
import com.clustercontrol.notify.bean.NotifyRequestMessage;
import com.clustercontrol.notify.bean.OutputBasicInfo;
import com.clustercontrol.notify.ejb.entity.NotifyJobInfoData;
import com.clustercontrol.notify.ejb.entity.NotifyJobInfoLocal;
import com.clustercontrol.notify.ejb.entity.NotifyJobInfoPK;
import com.clustercontrol.notify.ejb.entity.NotifyJobInfoUtil;
import com.clustercontrol.util.Messages;
import com.clustercontrol.util.apllog.AplLogger;

/**
 * ジョブを呼出すクラス<BR>
 *
 * @version 3.0.0
 * @since 3.0.0
 */
public class RunJob implements DependDbNotifier {
	/** ログ出力のインスタンス。 */
	private static Log m_log = LogFactory.getLog( RunJob.class );

	/** 実行失敗通知用 */
	private NotifyJobInfoData m_jobInfo;

	/**
	 * ジョブ管理機能の指定されたジョブを呼出します。
	 * <p>含まれているログ出力情報を基にジョブを呼出します。<BR>
	 * ジョブの呼出に失敗した場合は、ログ出力情報の呼出失敗時の重要度で、監視管理機能のイベントへ通知します。
	 * 
	 * @param outputInfo　通知・抑制情報
	 * @throws RemoteException
	 * @throws CreateException
	 * @throws NamingException
	 * @throws FinderException
	 * 
	 * @see com.clustercontrol.jobmanagement.bean.JobTriggerInfo
	 * @see com.clustercontrol.monitor.factory.OutputEventLog#insertEventLog(LogOutputInfo, int)
	 */
	@Override
	public synchronized void notify(NotifyRequestMessage message) throws RemoteException, NamingException, CreateException, FinderException {
		if(m_log.isDebugEnabled()){
			m_log.debug("notify() " + message);
		}

		exectuteJob(message.getOutputInfo(), message.getNotifyId());
	}

	/**
	 * ジョブ管理機能の指定されたジョブを呼出します。
	 * <p>含まれているログ出力情報を基にジョブを呼出します。<BR>
	 * ジョブの呼出に失敗した場合は、ログ出力情報の呼出失敗時の重要度で、監視管理機能のイベントへ通知します。
	 * 
	 * @param outputInfo　通知・抑制情報
	 * @throws RemoteException
	 * @throws CreateException
	 * @throws NamingException
	 * @throws FinderException
	 * 
	 * @see com.clustercontrol.jobmanagement.bean.JobTriggerInfo
	 * @see com.clustercontrol.monitor.factory.OutputEventLog#insertEventLog(LogOutputInfo, int)
	 */
	private void exectuteJob(
			OutputBasicInfo outputInfo,
			String notifyId) {
		if(m_log.isDebugEnabled()){
			m_log.debug("notify() " + outputInfo);
		}

		/*
		 * 実行
		 */
		NotifyJobInfoLocal jobInfo = null;
		try {
			jobInfo = NotifyJobInfoUtil.getLocalHome().findByPrimaryKey(
					new NotifyJobInfoPK(notifyId, outputInfo.getPriority()));

			// 実行対象のジョブが存在するかのチェック(存在しない場合はInternalイベントを出力して終了)
			try{
				JobValidator.validateJobId(jobInfo.getJobunitId(), jobInfo.getJobId());
			} catch (InvalidSetting e) {
				// 実行対象のジョブが存在しない場合の処理
				AplLogger apllog = new AplLogger("NOTIFY", "notify");
				String[] args = { notifyId, outputInfo.getMonitorId(), jobInfo.getJobunitId(), jobInfo.getJobId() };
				apllog.put("SYS", "008", args);

				m_log.warn(Messages.getString("message.notify.job.1", args));
				return;
			}


			// 通知設定が「固定スコープ」となっていた場合は、ジョブに渡すファシリティIDを変更する
			if(jobInfo.getJobExecFacilityFlg() == ExecFacilityConstant.TYPE_FIX) {
				outputInfo.setFacilityId(jobInfo.getJobExecFacility());
			}

			// ジョブの実行契機を作成
			JobTriggerInfo triggerInfo = new JobTriggerInfo();
			triggerInfo.setTrigger_type(JobTriggerTypeConstant.TYPE_MONITOR);
			triggerInfo.setTrigger_info(outputInfo.getMonitorId()+"-"+outputInfo.getPluginId()); // 「監視項目ID_プラグインID」形式で格納

			// ジョブ実行
			JobControllerLocal job = JobControllerUtil.getLocalHome().create();
			job.runJob(jobInfo.getJobunitId(), jobInfo.getJobId(), outputInfo, triggerInfo);

		}
		catch (Exception e) {
			if(jobInfo != null){
				m_jobInfo = new NotifyJobInfoData(
						jobInfo.getNotifyId(),
						jobInfo.getPriority(),
						jobInfo.getJobFailurePriority(),
						jobInfo.getJobunitId(),
						jobInfo.getJobId(),
						jobInfo.getValidFlg(),
						jobInfo.getJobExecFacilityFlg(),
						jobInfo.getJobExecFacility());
			}
			internalErrorNotify(notifyId, null, e.getMessage() + " : " + m_jobInfo);
		}
	}

	/**
	 * 通知失敗時の内部エラー通知を定義します
	 */
	@Override
	public void internalErrorNotify(String notifyId, String msgID, String detailMsg) {
		// FIXME
		//ジョブ失敗時の重要度を設定
		OutputBasicInfo outputInfo = new OutputBasicInfo();
		if(m_jobInfo != null){
			outputInfo.setPriority(m_jobInfo.getJobFailurePriority());
			String[] args1 = { m_jobInfo.getJobId() };
			outputInfo.setMessage(Messages.getString("message.monitor.41", args1));
		} else {
			outputInfo.setPriority(PriorityConstant.TYPE_CRITICAL);
			String[] args1 = { "unknown job id." };
			outputInfo.setMessage(Messages.getString("message.monitor.41", args1));
		}
		outputInfo.setMessageId("200");	// FIXME メッセージIDを精査する
		outputInfo.setMessageOrg(detailMsg);

		new OutputEvent().insertEventLog(outputInfo, ConfirmConstant.TYPE_UNCONFIRMED);

		m_jobInfo = null;
	}
}
